pub struct EntryMeta {
pub received_at_unix_ms: u64,
pub delivery_id: String,
pub path: PathBuf,
}Expand description
One entry as described by its filename alone — no file was opened.
Fields
received_at_unix_ms: u64When console accepted the delivery. Sorts first so a plain sort is an age sort.
delivery_id: StringThe sanitised delivery id from the filename.
path: PathBufAbsolute path of the entry file.